diff options
| author | Guido van Rossum <guido@python.org> | 1997-01-18 02:46:13 +0000 |
|---|---|---|
| committer | Guido van Rossum <guido@python.org> | 1997-01-18 02:46:13 +0000 |
| commit | 3dfd53b4c83cc42e694a7c6e66678f2e7b0b1613 (patch) | |
| tree | e669c605397711929baec5d04388d2e9b1296264 /Include/stringobject.h | |
| parent | 04f2b453bbc282be83529b6fb726dc92dbbdbfc3 (diff) | |
| download | cpython-git-3dfd53b4c83cc42e694a7c6e66678f2e7b0b1613.tar.gz | |
Add "if (x != NULL) continue;" (or similar for err==0) before the
break to most cases, as suggested by Tim Peters. This gives another
8-10% speedup.
Diffstat (limited to 'Include/stringobject.h')
0 files changed, 0 insertions, 0 deletions
